@@ -44,6 +44,9 @@ FAILEDOPERATION_CLUSTERSTATE = 'FailedOperation.ClusterState'
 # 集群节点版本过低。
 FAILEDOPERATION_CLUSTERUPGRADENODEVERSION = 'FailedOperation.ClusterUpgradeNodeVersion'
 
+# 内部Client错误。
+FAILEDOPERATION_COMPONENTCLIENTCOMMON = 'FailedOperation.ComponentClientCommon'
+
 # 内部HTTP客户端错误。
 FAILEDOPERATION_COMPONENTCLIENTHTTP = 'FailedOperation.ComponentClientHttp'
 
@@ -71,6 +74,9 @@ FAILEDOPERATION_DBRECORDNOTFOUND = 'FailedOperation.DbRecordNotFound'
 # 获得安全组配额失败。
 FAILEDOPERATION_DFWGETUSGQUOTA = 'FailedOperation.DfwGetUSGQuota'
 
+# 查询主题集失败。
+FAILEDOPERATION_GETCLSLOGSET = 'FailedOperation.GetClsLogSet'
+
 # 连接用户Kubernetes集群失败。
 FAILEDOPERATION_KUBECLIENTCONNECTION = 'FailedOperation.KubeClientConnection'
 
@@ -323,6 +329,9 @@ INTERNALERROR_VPCPEERNOTFOUND = 'InternalError.VpcPeerNotFound'
 # 未发现vpc记录。
 INTERNALERROR_VPCRECODRNOTFOUND = 'InternalError.VpcRecodrNotFound'
 
+# VstationError。
+INTERNALERROR_VSTATIONERROR = 'InternalError.VstationError'
+
 # 白名单未知错误。
 INTERNALERROR_WHITELISTUNEXPECTEDERROR = 'InternalError.WhitelistUnexpectedError'
 
@@ -365,6 +374,9 @@ INVALIDPARAMETER_GATEWAYALREADYASSOCIATEDCIDR = 'InvalidParameter.GatewayAlready
 # 无效的私有CIDR网段。
 INVALIDPARAMETER_INVALIDPRIVATENETWORKCIDR = 'InvalidParameter.InvalidPrivateNetworkCIDR'
 
+# 镜像OS不支持。
+INVALIDPARAMETER_OSNOTSUPPORT = 'InvalidParameter.OsNotSupport'
+
 # 参数错误。
 INVALIDPARAMETER_PARAM = 'InvalidParameter.Param'
 
